package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````$"D```````!``````````%C!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````+`9````````L!D`````````
M$`````````$````%`````"``````````(``````````@````````+4,`````
M```M0P`````````0`````````0````0`````<`````````!P`````````'``
M``````"`1@```````(!&`````````!`````````!````!@```,B[````````
MR,L```````#(RP```````&`$````````B`0`````````$`````````(````&
M````V+L```````#8RP```````-C+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``#`L````````,"P````````P+`````````$`0````````0!````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````R+L```````#(RP```````,C+````
M````.`0````````X!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`DC-;AK).C$>K`#-X
M+Q3"]$ZZQ9,$````$`````$```!'3E4```````,````"```````````````1
M````0P````0````(````(!`0``5`!(0H`@`$@(8`A(*)``()(`0(B(`10;H`
M`@@`````0P```$8```!)````2@```%(```!3````5`````````!6````5P``
M`%@```!9````6P```%T``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9G
MK\QF0D75[(D'<-,S8MOM%8PES`TZEPM^J9R;T67.;>"G`@IK&IY0H^#[20``
M`````````````````````````````*8"```2````````````````````````
M``T"```2`````````````````````````(P````1````````````````````
M`````(T"```2`````````````````````````#X!```2````````````````
M`````````.@!```2`````````````````````````$D"```2````````````
M``````````````$````@`````````````````````````+@!```2````````
M`````````````````&<````2`````````````````````````,4!```2````
M`````````````````````)0````2`````````````````````````(8"```2
M`````````````````````````-@"```2`````````````````````````/T!
M```2`````````````````````````-(````2````````````````````````
M`.(````2`````````````````````````#`!```2````````````````````
M`````'$!```2`````````````````````````&H!```2````````````````
M`````````(H````1`````````````````````````((#```2````````````
M`````````````!`````@`````````````````````````+X"```2````````
M`````````````````*L"```2`````````````````````````+T````2````
M`````````````````````"P````@`````````````````````````)T````2
M`````````````````````````*L````2`````````````````````````*D!
M```2`````````````````````````+`"```2````````````````````````
M`.@````6`````````````````````````/L````2````````````````````
M`````%P"```2`````````````````````````!8!```2````````````````
M`````````,D"```2`````````````````````````)H!```2````````````
M`````````````/8!```2`````````````````````````$4!```2````````
M`````````````````"<!```2`````````````````````````'X!```2````
M`````````````````````)@"```2`````````````````````````-<!```2
M`````````````````````````(4!```2`````````````````````````"X"
M```2`````````````````````````'D````2````````````````````````
M`),!```2`````````````````````````(P!```2````````````````````
M`````)P````2`````````````````````````,H!```2````````````````
M`````````!D"```2`````````````````````````'H"```2````````````
M`````````````+T!```2`````````````````````````-D````2````````
M`````````````````,0````2`````````````````````````*(!```1````
M`````````````````````&T"```1`````````````````````````*0````2
M`````````````````````````&(!```2``````````````````````````L!
M```2`````````````````````````%0!```2````````````````````````
M`#H"```2`````````````````````````$8````2````````````````````
M`````.$"```2`````````````````````````+,````2````````````````
M`````````-$!```2`````````````````````````(L#```2`!``@%T`````
M``#7`````````.`#```2`!``<%,```````#7!P```````%,````2`!```"<`
M```````.`@````````(#```2`!``X$<````````)`````````"`#```2`!``
M4%L````````P`@````````8$```2`!``\$<````````2`@```````,8#```0
M`!H`*-```````````````````!,#```2`!``$$H````````R`````````#8#
M```2`!```%````````!I`````````)<#```1`!(``'`````````$````````
M`+,#```2`!``L%X```````"W`0```````+X#```2`!``T$8````````I````
M`````-L#```0`!H`4-```````````````````/0#```2`!``D%(```````#>
M`````````!T$```2`!``<%````````#``````````*8#```0`!D``-``````
M`````````````%H#```2`!``4$H```````!!`0```````.T#```0`!D`*-``
M`````````````````!,$```1`!D`(-`````````(`````````*P#```2`!``
M$"D````````F`````````-(#```2`!``8%X```````!&`````````*@#```@
M`!D``-```````````````````'`#```2`!``<%(````````>`````````%@`
M```B`````````````````````````$0#```2`!```$<```````#=````````
M`&8#```2`!``<&````````"5`@```````"4$```2`!``H$L```````!;!```
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I
M;@!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H
M:U]F86EL`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD
M:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S
M961I<@!R;61I<@!03%]C=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A9&5R
M`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!097)L7W-V
M7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!?7VUE;6UO=F5?8VAK`')E
M86QL;V,`9V5T<&ED`%]?;65M8W!Y7V-H:P!S=')C:'(`<W1R9'5P`'-T<G1O
M:P!S=')C;7``<W1R<F-H<@!S=&1E<G(`7U]V9G!R:6YT9E]C:&L`97AI=`!L
M<V5E:S8T`')E860`9V5T=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F
M<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O
M7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L7V1E
M<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`<&5R
M;%]C;VYS=')U8W0`<&5R;%]R=6X`;65M8W!Y`&QI8G!E<FPN<V\N-2XS.`!L
M:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O
M;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?
M<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET
M`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,
M24)#7S(N,30`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"
M0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C(N-0`````!``$``@`!``(`
M`P`!``$``@`$``(``@`"``$``0`"``(``0`#``(``@`"``$``0`"``(``0`%
M``(``P`!``$``0`!``$``0`"``(``0`"``(``0`"``(``0`&``(``@`%``(`
M`0`!``(``@`#``(``0`"``(``0`#``$`!P`(``(``@`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``@`!``$``0````$`
M!P#X`@``$`````````"4D98&```(`#($```0````M)&6!@``!P`]!```$```
M`!1I:0T```8`2`0``!````"SD98&```%`%($```0````<AEI"0``!`!=!```
M$````'09:0D```,`:00``!````!U&FD)```"`'4$````````R,L````````(
M`````````/`I````````T,L````````(`````````+`I````````"-``````
M```(``````````C0````````(-`````````(`````````/AR````````H,\`
M```````&`````P``````````````J,\````````&````!P``````````````
ML,\````````&````"```````````````N,\````````&````%P``````````
M````P,\````````&````&P``````````````R,\````````&````6@``````
M````````T,\````````2````(```````````````V,\````````&````(0``
M````````````X,\````````&````(@``````````````Z,\````````&````
M.```````````````\,\````````&````.0``````````````^,\````````&
M````/P``````````````\,T````````'`````0``````````````^,T`````
M```'`````@```````````````,X````````'````!```````````````",X`
M```````'````!0``````````````$,X````````'````!@``````````````
M&,X````````'````"0``````````````(,X````````'````"@``````````
M````*,X````````'````"P``````````````,,X````````'````#```````
M````````.,X````````'````#0``````````````0,X````````'````#@``
M````````````2,X````````'````#P``````````````4,X````````'````
M$```````````````6,X````````'````$0``````````````8,X````````'
M````$@``````````````:,X````````'````$P``````````````<,X`````
M```'````%```````````````>,X````````'````%@``````````````@,X`
M```````'````&```````````````B,X````````'````&0``````````````
MD,X````````'````&@``````````````F,X````````'````'```````````
M````H,X````````'````'0``````````````J,X````````'````'@``````
M````````L,X````````'````'P``````````````N,X````````'````(P``
M````````````P,X````````'````)```````````````R,X````````'````
M)0``````````````T,X````````'````)@``````````````V,X````````'
M````)P``````````````X,X````````'````*```````````````Z,X`````
M```'````*0``````````````\,X````````'````*@``````````````^,X`
M```````'````*P```````````````,\````````'````+```````````````
M",\````````'````+0``````````````$,\````````'````+@``````````
M````&,\````````'````+P``````````````(,\````````'````,```````
M````````*,\````````'````,0``````````````,,\````````'````,@``
M````````````.,\````````'````,P``````````````0,\````````'````
M-```````````````2,\````````'````-0``````````````4,\````````'
M````-@``````````````6,\````````'````-P``````````````8,\`````
M```'````.@``````````````:,\````````'````.P``````````````<,\`
M```````'````/```````````````>,\````````'````/0``````````````
M@,\````````'````/@``````````````B,\````````'````0```````````
M````D,\````````'````00``````````````F,\````````'````0@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&O``!(A<!T`O_02(/$",,``````/\UNJT``/\EO*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OIH-0```.F2_/__9I#S#Q[Z_R4NK```9@\?1```\P\>^O\E1JH``&8/'T0`
M`/,/'OK_)3ZJ``!F#Q]$``#S#Q[Z_R4VJ@``9@\?1```\P\>^O\E+JH``&8/
M'T0``/,/'OK_)2:J``!F#Q]$``#S#Q[Z_R4>J@``9@\?1```\P\>^O\E%JH`
M`&8/'T0``/,/'OK_)0ZJ``!F#Q]$``#S#Q[Z_R4&J@``9@\?1```\P\>^O\E
M_JD``&8/'T0``/,/'OK_)?:I``!F#Q]$``#S#Q[Z_R7NJ0``9@\?1```\P\>
M^O\EYJD``&8/'T0``/,/'OK_)=ZI``!F#Q]$``#S#Q[Z_R76J0``9@\?1```
M\P\>^O\ESJD``&8/'T0``/,/'OK_)<:I``!F#Q]$``#S#Q[Z_R6^J0``9@\?
M1```\P\>^O\EMJD``&8/'T0``/,/'OK_):ZI``!F#Q]$``#S#Q[Z_R6FJ0``
M9@\?1```\P\>^O\EGJD``&8/'T0``/,/'OK_)9:I``!F#Q]$``#S#Q[Z_R6.
MJ0``9@\?1```\P\>^O\EAJD``&8/'T0``/,/'OK_)7ZI``!F#Q]$``#S#Q[Z
M_R5VJ0``9@\?1```\P\>^O\E;JD``&8/'T0``/,/'OK_)6:I``!F#Q]$``#S
M#Q[Z_R5>J0``9@\?1```\P\>^O\E5JD``&8/'T0``/,/'OK_)4ZI``!F#Q]$
M``#S#Q[Z_R5&J0``9@\?1```\P\>^O\E/JD``&8/'T0``/,/'OK_)3:I``!F
M#Q]$``#S#Q[Z_R4NJ0``9@\?1```\P\>^O\E)JD``&8/'T0``/,/'OK_)1ZI
M``!F#Q]$``#S#Q[Z_R46J0``9@\?1```\P\>^O\E#JD``&8/'T0``/,/'OK_
M)0:I``!F#Q]$``#S#Q[Z_R7^J```9@\?1```\P\>^O\E]J@``&8/'T0``/,/
M'OK_)>ZH``!F#Q]$``#S#Q[Z_R7FJ```9@\?1```\P\>^O\EWJ@``&8/'T0`
M`/,/'OK_)=:H``!F#Q]$``#S#Q[Z_R7.J```9@\?1```\P\>^O\EQJ@``&8/
M'T0``/,/'OK_);ZH``!F#Q]$``#S#Q[Z_R6VJ```9@\?1```\P\>^O\EKJ@`
M`&8/'T0``/,/'OK_)::H``!F#Q]$``#S#Q[Z_R6>J```9@\?1```\P\>^E5(
MB>5!5%-(@^PPB7W<2(U]W$B)==!(C7702(E5R$B-5<AD2(L$)2@```!(B47H
M,<#HAO___TB+-6>H``!(BSV8J```2(GRZ,`[``!(BP69J```@#@`#X0:`0``
M2(L%::@``&1(BP"`B#H$```#BT7<C7@$C5@#2&/_2,'G`^BY_O__2(M-T$2+
M1=Q(B<9(B06OJ```2(L!2(D&2(T%04H``$B)1@A(C05OJ```2(L`2(E&$$B-
M!2M*``!(B48808/X`0^.*`$``$B#P0A!@\`#N`0```!F#Q]$``!(BSE(8]"#
MP`%(@\$(2(D\UD0YP'7J2)A(BSTYJ```13'`2(GQ2,<$Q@````")VDB--2H;
M``#HI?O__X7`#X2'````2(L]#J@``$R-9>3H;?W__TR)YDB-/69(``")PS'`
MZ`H8``!(A<!T<$B+/>:G``#H2?O__^C$_/__2(M%Z&1(*P0E*`````^%F@``
M`$B#Q#")V%M!7%W#Z$'\__](B06RIP``2(G'2(7`=''HK?S__TB+!3:G``!D
M2(L0QH(N"0```.F]_O__2(L]AZ<``.B*^___Z6C___](BSU^IP``2(7_=`KH
MM#0``.EZ____2(T]@$<``$R)YNAP%P``2(D%6:<``$B)QTB%P`^$6/___^O2
MN`0```#I]_[__[\!````Z.?Z___HTOS__V:0\P\>^C'M28G17DB)XDB#Y/!0
M5$4QP#')2(T]T?W___\5PZ8``/1F+@\?A```````2(T]X:8``$B-!=JF``!(
M.?AT%4B+!5ZF``!(A<!T"?_@#Q^``````,,/'X``````2(T]L:8``$B--:JF
M``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%):8``$B%P'0(_^!F#Q]$``##
M#Q^``````/,/'OJ`/6VF````=2M52(,]`J8```!(B>5T#$B+/3:F``#HN?G_
M_^AD____Q@5%I@```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````54B)
M^DR-1SA(B>5!5T%62(V-0/W__TR-C<#]__]!54B)ST%44TB![)@"``!D2(L$
M)2@```!(B47(,<`/'T0``$&+`$V+$$B#QQ!)@\`(#\B)P$R)UDB)1_!,B=!(
MP>X@2,'H*$G!ZC@E`/\``$P)T$F)\DC!Y@A)P>(8@>8``/\`18G23`G02`GP
M2(E'^$PYSW6M9@]OC5#]__]F#V^=8/W__TB-A:C]__](@<%H`@``9@]OE7#]
M__]F#V\MOX4```\?@`````#S#V\`9@]OXF8/;U#82(/`$&8/[TB(9@_OPF8/
M[\%F#V_(9@]ST!]F#W/Q`68/Z\%F#V_+9@]OW&8/V\4/*4`(2#G(=;M,BPI,
MBUH02(MZ($B+6AA,B<A,B<E,BX5(_?__2,'I&TC!X`5("<@#A4#]__].C80#
MF7F"6HV,.)EY@EI,B=A(,=A((T((2#'8C3P!2(M*"$B+0@A)B?I(P>@"2,'A
M'D@)P4R)V$G!ZAN)SD@Q\$PAR$PQV$P!P$F)^$G!X`5-"=!&C20`3(G(38G(
M2<'H`DC!X!Y-B>5,"<!,BX50_?__2<'M&T@QP4&)PD@A^4^-A`.9>8):2#'Q
M3`'!38G@2<'@!4T)Z$R+K5C]__]!`<A(B?E(P>\"2,'A'D6)P$J-M"Z9>8):
M2`GY38G%2#'(B<],(>!)P>T;3#'02`'P3(G&2,'F!4P)[DR+K6#]__\!QDR)
MX$G![`)(P>`>B?9/C90JF7F"6DP)X$F)]4@QP4G![1M!B<1,(<%(,?E,`=%)
MB?))P>(%30GJ3(NM:/W__T$!RDR)P4G!Z`)(P>$>18G22HV\+YEY@EI,"<%-
MB=5(,<A)P>T;08G(2"'P3#'@2`'X3(G72,'G!4P)[TR+K7#]__\!QTB)\$C!
M[@)(P>`>B?]/C:0LF7F"6D@)\$F)_4@QP4G![1N)QDPAT4PQP4P!X4F)_$G!
MY`5-">Q,BZUX_?__00',3(G12<'J`DC!X1Y%B>1/C80HF7F"6DP)T4V)Y4@Q
MR$G![1M!B<I((?A(,?!,`<!-B>!)P>`%30GH3(NM@/W__T$!P$B)^$C![P)(
MP>`>18G`2HVT+IEY@EI("?A-B<5(,<%)P>T;B<=,(>%,,=%(`?%,B<9(P>8%
M3`GN3(NMB/W__P'.3(GA2<'L`DC!X1Z)]D^-E"J9>8):3`GA28GU2#'(2<'M
M&T&)S$PAP$@Q^$P!T$F)\DG!X@5-">I,BZV0_?__00'"3(G`2<'H`DC!X!Y%
MB=)*C;POF7F"6DP)P$V)U4@QP4G![1M!B<!((?%,,>%(`?E,B==(P><%3`GO
M3(NMF/W__P'/2(GQ2,'N`DC!X1Z)_T^-I"R9>8):2`GQ28G]2#'(2<'M&XG.
M3"'03#'`3`'@28G\2<'D!4T)[$R+K:#]__]!`<1,B=!(P>`>2<'J`D6)Y$^-
MA"B9>8):3`G038GE2#'!2<'M&T&)PD@A^4@Q\4P!P4V)X$G!X`5-">A,BZVH
M_?__00'(2(GY2,'O`DC!X1Y%B<!*C;0NF7F"6D@)^4V)Q4@QR$G![1N)STPA
MX$PQT$@!\$R)QDC!Y@5,">Y,BZVP_?__`<9,B>!)P>P"2,'@'HGV3XV4*IEY
M@EI,">!)B?5(,<%)P>T;08G$3"'!2#'Y3`'128GR2<'B!4T)ZDR+K;C]__]!
M`<I,B<%(P>$>2<'H`D6)TDJ-O"^9>8):3`G!38G52#'(2<'M&T&)R$@A\$PQ
MX$@!^$R)UTC!YP5,">],BZW`_?__`<=(B?!(P>X"2,'@'HG_3XVD+)EY@EI(
M"?!)B?U(,<%)P>T;B<9,(=%,,<%,`>%)B?Q)P>0%30GL1HTT(4R)T4G!Z@)(
MP>$>3`G13(N5R/W__T@QR$&)S$@A^$^-A!"9>8):38GR2#'P2<'J&TP!P$V)
M\$G!X`5-"=!,BY70_?__00'`2(GX2,'@'DC![P)%B<!*C;06F7F"6D@)^$V)
MPD@QP4G!ZAN)QTPA\4PQX4@!SDR)P4C!X05,"=%-B?))P>X"2<'B'HG)30GR
M2`'.2(N-V/W__TPQT$&)]4PAP$F-C`R9>8):38GL2#'X2<'L&T@!R$R)Z4C!
MX05,">&)R4@!R$R)P4G!Z`)(P>$>08G$3`G!38G018G223'(1#'&3(N%X/W_
M_TJ-O`>AZ]EN38G@2`'W3(GF2<'H&TC!Y@5,"<:)]D@!]TR)[DC!YAY)P>T"
M08GX3`.5Z/W__TP)[DF)S8G)2`.-\/W__TDQ]40QZ$V)Q4V-E`*AZ]EN3(G`
M2<'M&TC!X`5,">B)P$D!PDR)X$G![`)(P>`>18G53`G@28GTB?9(`[7X_?__
M23'$1#'G38GL2(V\.:'KV6Y,B>E)P>P;2,'A!4P)X8G)2`'/3(G!2<'H`DC!
MX1Y!B?Q,"<%)B<")P$DQR$4QT$V)XDZ-A`:AZ]EN3(GF2<'J&TC!Y@5,"=:)
M]DD!\$R)[DG![0)(P>8>18G"3`GN28G-2`.%`/[__XG)23'U2`.-"/[__T0Q
M[TV)U4B-O#BAZ]EN3(G02<'M&TC!X`5,">B)P$@!QTR)X$G![`)(P>`>08G]
M3`G@28GTB?9(`[40_O__23'$13'@38GL3HV$`:'KV6Y,B>E)P>P;2,'A!4P)
MX8G)20'(3(G12<'J`DC!X1Y%B<1,"=%)B<*)P$@#A1C^__]),<I$,==-B>)(
MC;P^H>O9;DR)YDG!ZAM(P>8%3`G6B?9(`?=,B>Y)P>T"2,'F'D&)^DP)[DF)
MS8G)23'U2`.-(/[__T4QZ$V)U4Z-A`"AZ]EN3(G02<'M&TC!X`5,">B)P$D!
MP$R)X$G![`)(P>`>18G%3`G@28GTB?9(`[4H_O__23'$1#'G38GL2(V\.:'K
MV6Y,B>E)P>P;2,'A!4P)X8G)2`'/3(G12<'J`DC!X1Y!B?Q,"=%)B<*)P$@#
MA3#^__]),<I%,=!-B>).C80&H>O9;DR)YDG!ZAM(P>8%3`G6B?9)`?!,B>Y)
MP>T"2,'F'D6)PDP)[DF)S8G)23'U1#'O38G52(V\.*'KV6Y,B=!(P>`%2<'M
M&T@#C3C^__],">B)P$@!QTR)X$G![`)(P>`>08G]3`G@28GTB?9(`[5`_O__
M23'$13'@38GL3HV$`:'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G12<'J`DC!
MX1Y%B<1,"=%)B<*)P$@#A4C^__]),<I$,==-B>)(C;P^H>O9;DR)YDG!ZAM(
MP>8%3`G6B?9(`?=,B>Y)P>T"2,'F'D&)^DP)[DF)S8G)23'U13'H38G53HV$
M`*'KV6Y,B=!)P>T;2,'@!4P)Z$@#C5#^__^)P$D!P$R)X$G![`)(P>`>18G%
M3`G@28GTB?9(`[58_O__23'$1#'G38GL2(V\.:'KV6Y,B>E)P>P;2,'A!4P)
MX8G)2`'/3(G12<'J`DC!X1Y!B?Q,"=%)B<*)P$@#A6#^__]),<I%,=!-B>).
MC80&H>O9;DR)YDG!ZAM(P>8%3`G6B?9)`?!,B>Y)P>T"2,'F'D6)PDP)[DF)
MS8G)23'U1#'O38G52(V\.*'KV6Y,B=!)P>T;2,'@!4P)Z(G`2`''3(G@2,'@
M'DG![`)!B?U(`XUH_O__3`G@28GTB?9(`[5P_O__23'$13'@3HVD`:'KV6Y,
MB>E-B>A)P>@;2,'A!4P)P8G)20',3(G12<'J`DC!X1Y%B>!,"=%)B<*)P$@#
MA7C^__]),<I$,==-B<)(C;P^H>O9;DR)QDG!ZAM(P>8%3`G638GJ2<'M`DG!
MXAX!]TB)SHG)30GJB?],,=9-B=9%B=5$,>9)B?Q(C;0PH>O9;DB)^$G![!M(
MP>`%3`G@1(TD!DR)QDG!Z`*XW+P;CTC!YAY,"<9)"?9!B?!-(<))(?Y-"=9,
MBY6`_O__20'"3`'138GB3`'Q38GF2<'B!4G![AM-"?)!`<I(B?E(P>\"2,'A
M'D6)TD@)^4@)SDF)SHG/3"'F32'&20GV2(NUB/[__T@!QDP![DV)U4P!]DV)
MUDG!Y05)P>X;30GU28G.00'U3(GF2<'L`DC!YAY%B>U,">9!B?1)"?9-(=9,
M(>%,"?%,B[60_O__20'&30'&38GH3`'Q38GN2<'@!4G![AM-"?!!`<A,B=%)
MP>H"2,'A'D6)P$P)T4@)SDF)SD&)RDPA[DTAYDD)]DB+M9C^__](`<9(`?Y,
MB<=,`?9-B<9(P><%2<'N&TP)]TF)S@'W3(GN2<'M`DC!YAZ)_TP)[D&)]4D)
M]DTAQDPAZ4P)\4R+M:#^__])`<9-`>9)B?Q,`?%)B?Y)P>0%2<'N&TT)]$$!
MS$R)P4G!Z`)(P>$>18GD3`G!2`G.28G.08G(2"'^32'N20GV2(NUJ/[__T@!
MQDP!UDV)XDP!]DV)YDG!X@5)P>X;30GR28G.00'R2(G^2,'O`DC!YAY%B=)(
M"?Z)]TD)]DTAYD@A^4P)\4R+M;#^__])`<9-`>Y-B=5,`?%-B=9)P>4%2<'N
M&TT)]4$!S4R)X4C!X1Y)P>P"18GM3`GA2`G.28G.08G,3"'622'^20GV2(NU
MN/[__T@!QDP!QDV)Z$P!]DV)[DG!X`5)P>X;30GP28G.00'P3(G62<'J`DC!
MYAY%B<!,"=9!B?))"?9-(>Y,(=%,"?%,B[7`_O__20'&20'^3(G'3`'Q38G&
M2,'G!4G![AM,"?<!STR)Z4G![0)(P>$>B?],">E("<Y)B<Y!B<U,(<9-(=9)
M"?9(B[7(_O__2`'&3`'F28G\3`'V28G^2<'D!4G![AM-"?1)B<Y!`?1,B<9)
MP>@"2,'F'D6)Y$P)QD&)\$D)]DDA_DPAP4P)\4R+M=#^__])`<9-`=9-B>),
M`?%-B>9)P>(%2<'N&TT)\D$!RDB)^4C![P)(P>$>18G22`GY2`G.28G.B<],
M(>9-(<9)"?9(B[78_O__2`'&3`'N38G53`'V38G62<'E!4G![AM-"?5)B<Y!
M`?5,B>9)P>P"2,'F'D6)[4P)YD&)]$D)]DTAUDPAX4P)\4R+M>#^__])`<9-
M`<9-B>A,`?%-B>Y)P>`%2<'N&TT)\$$!R$R)T4G!Z@)(P>$>18G`3`G12`G.
M28G.08G*3"'N32'F20GV2(NUZ/[__T@!QD@!_DR)QTP!]DV)QDC!YP5)P>X;
M3`GW28G.`?=,B>Y)P>T"2,'F'HG_3`GN08GU20GV32'&3"'I3`GQ3(NU\/[_
M_TD!QDT!YDF)_$P!\4F)_DG!Y`5)P>X;30GT00',3(G!2<'H`DC!X1Y%B>1,
M"<%("<Y)B<Y!B<A((?Y-(>Y)"?9(B[7X_O__2`'&3`'638GB3`'V38GF2<'B
M!4G![AM-"?))B<Y!`?)(B?Y(P>\"2,'F'D6)TD@)_DD)]HGW32'F2"'Y3`GQ
M3(NU`/___TD!QDT![DV)U4P!\4V)UDG!Y05)P>X;30GU00'-3(GA2<'L`DC!
MX1Y%B>U,">%("<Y)B<Q!B<],(=9)(?Q)"?1(B[4(____2`'&3`'&38GH3`'F
M38GL2<'@!4G![!M-">!!`?!,B=9)P>H"2,'F'D6)P$P)UDF)RD&)]$D)\DTA
MZDPAX4P)T4R+E1#___])`<)(`X48____3`'738G"3`'X3(N]./___T@!STR)
MP4G!ZAM(P>$%3`G1B<E(`<],B>E)P>T"2,'A'D&)^DP)Z4@)SDF)S4&)SDPA
MQDTAY4D)]4F-=`4`3(G038G52<'M&TC!X`5,">B)P$@!QDR)P$G!Z`)(P>`>
M08GU20G`N-;!8LI,,<$Q^4B+O2#___](`<=,`>=-B>Q(`?E,B>])P>P;2,'G
M!4P)YTV)U(G_2`'Y2<'D'DD!QTG!Z@*)STT)XDV)Q$6)P$TQU$$Q]$B+M2C_
M__](`<9,`?9)B?Y,`>9)B?Q)P>X;2<'D!4T)]$V)[DG![0))P>8>18GD30GU
M3(NU,/___TP!YD&)]$D!QDT!\$V)UDTQ[D$QSDR)X4T!\$V)YDC!X05)P>X;
M3`GQB<E)`<A(B?E(P>\"2,'A'D6)QD@)ST2)T4V)ZDDQ^DP!^4R+O4#___]!
M,?)*C3013(GQ38GR2,'A!4G!ZAM)`<=,"=&)R4@!SDR)X4G![`)(P>$>08GR
M3`GA18GL28G]B?]),<U-`?Q,B[U8____13'%3XT$+$V)U$V)U4G![1M)P>0%
M30GL38GU2<'N`DG!Y1Y%B>1-">Y,BZU(____30'@18G$20'%3`'O28G-B<E-
M,?5!,?5,B>9,`>]-B>5(P>8%2<'M&TP)[HGV2`'W3(G62<'J`DC!YAY!B?U,
M"=9,BY50____20'"3`'138GR23'R13'"20''3HT$$4R)Z4V)ZDG!ZAM(P>$%
M3`G1B<E)`<A,B>%)P>P"2,'A'D6)PDD)S$2)\4F)]HGV33'F3`'Y3(N]:/__
M_T$Q_DJ-/#%,B=%-B=9)`<=)P>X;2,'A!4P)\8G)2`'/3(GI2<'M`DC!X1Y!
MB?Y,">E,BZU@____20'%3`'N38GE23'-13'%3HT$+DR)]DV)]4G![1M(P>8%
M3`GNB?9)`?!,B=9)P>H"2,'F'D6)Q4D)\D2)YDF)S(G)3`'^33'43(N]>/__
M_T$Q_$J-/"9,B>Y-B>Q)`<=)P>P;2,'F!4P)YHGV2`'W3(GV2<'N`DC!YAY!
MB?Q,"?9,B[5P____20'&3`'Q38G623'V13'&3HT$,4R)X4V)YDG![AM(P>$%
M3`GQB<E)`<A,B>E)P>T"2,'A'D6)QDD)S42)T4F)\HGV33'J3`'Y3(M]B$$Q
M^DJ-/!%,B?%-B?))P>H;2,'A!4P)T8G)2`'/3(GA2<'L`DC!X1Y!B?I,">%,
MBV6`20'$3`'F38GL20''23',13'$3HT$)DR)UDV)U$G![!M(P>8%3`GFB?9)
M`?!,B?9)P>X"2,'F'D6)Q$D)]D2)[DF)S8G)33'U3`'^3(M]F$$Q_4J-/"Y,
MB>9-B>5)P>T;2,'F!4P)[HGV2`'W3(G62<'J`DC!YAY!B?U,"=9,BU6020'"
M3`'138GR23'R13'"3HT$$4R)Z4V)ZDG!ZAM(P>$%3`G1B<E)`<A,B>%)P>P"
M2,'A'D6)PDD)S$2)\4F)]DD!QTTQYDP!^8GV3(M]J$$Q_DR)UTD!SDR)T4C!
M[QM)`<=(P>$%2`GYB<E)`<Y,B>E)P>T"2,'A'D2)]TP)Z4R+;:!)`<5,`>Y-
MB>5),<U%,<5.C00N2(G^28G]2<'M&TC!Y@5,">Z)]DD!\$R)UDG!Z@)(P>8>
M18G%20GR1(GF28G,B<E-,=1,`?Y%,?1-B>Y,`>9-B>Q)P>X;2<'D!4T)]$F)
M_D6)Y$P!YDG!YAY(P>\"08GT3`GW3(MUL$D!QD@#1;A,`?%-B=9,`<A%B=))
M,?Y,`=!%,<9-B>!,`?%-B>9)P>`%2<'N&TT)\$0!P4V)Z$G![0))P>`>B<E-
M"<5)B?@#>B!-,>A!`=U(B7H@1#'&28G(3(EJ&$@!\$B)SDG!Z!L#2@A(P>8%
M2(E*"$P)Q@'P2(D"3(G@2<'L`DC!X!Y,">!$`=A(B4(02(M%R&1(*P0E*```
M`'422('$F`(``%M!7$%=05Y!7UW#Z)WE__]F9BX/'X0``````&:054B)Y4%7
M059!54%44TB#[!A(B77(2(7_#X2R````2(L%*X\``$R+,$V%]@^$GP````^V
M!TF)_83`=`0\/75113'D28L>2(7;="Q-8^1-B?=,B>),B>Y(B=_H<N/__X7`
M=0="@#PC/71'28M?"$F#QPA(A=MUVDB#Q!A(B=A;05Q!74%>05]=PP\?A```
M````28G\00^V1"0!28/$`83`=`0\/77N12GLZYAF#Q]$``!,B?E(BT7(2HU<
M(P%,*?%(P?D#B0CKKV8/'X0``````#';ZZ)F9BX/'X0``````)!52(GE4TB)
M^TB-M5#___](@>RH````9$B+!"4H````2(E%Z#'`Z+;D__^%P'4ZBY5H____
M@>(`\```@?H`0```=`B!^@"@``!U(+X"````2(G?Z/GD__^%P`^4P`^VP.L)
M#Q^``````#'`2(M5Z&1(*Q0E*````'4&2(M=^,G#Z"SD__]F9BX/'X0`````
M`)!52(GE05=!5D%505132('LJ````&1(BP0E*````$B)1<@QP$B%_W0(@#\`
M2(G[=2A(BT7(9$@K!"4H````#X4L`0``2('$J````%M!7$%=05Y!7UW##Q\`
MZ./B__])B<5(A<!TRTR)[^BSY/__2(7`#X2Z````@'@3+DR-8!-U$$&`?"0!
M`'3=#Q^$``````"`>!,N#X2N````2(G?Z'[B__],B>=)B<;H<^+__T6-?`8"
M36/_3(G_Z+/A__]-B>%)B=A,B?I)B<9(B<>^`@```#'`2(T-:BT``.C1X___
M3(GW2(VU,/___^A"XO__3(GW@_C_=!*+A4C___\E`/```#T`0```=&#HD^'_
M_TR)]^C[X?__3(GOZ`/D__](A<`/A5#___]F+@\?A```````3(GOZ&CC__](
MB=_H<.'__^GK_O__#Q\`08!\)`$N#X5&____08!\)`(`#X0%____Z37___\/
M'P#HD_[__^N>Z*SB__]F9BX/'X0``````)#S#Q[Z54B-#21M``!(C36W+```
M2(GE4TB#[`A(BQUNC```2(L5;XP``&1(BSOH+N/__V1(BSM(BUWX13')2(T5
MS!<``$R-!3DN``!(C364+```R4R)P>F5X?__#Q]$``!52(GE059!54%44TB!
M[``0``!(@PPD`$B#[!"Z_P\``&1(BP0E*````$B)1=@QP$R-K=#O__](B?M)
MB?1(C3U8+```3(GNZ)7A__^%P'X6B<&#Z`%(8]"`O!70[___`'5'A<!U.TB+
M!<2+``!,B>)(B=YD2(LXZ&7@__](BT789$@K!"4H````=5%(@<00$```6T%<
M05U!7EW#9@\?1```B<%F#Q]$``!,8_&^+P```$R)[TR)\NAUW___2(7`=*5(
MBP5IBP``3(GQ3(GJ2(G>9$B+..CWX/__ZZ#H8.'__U5(B>5!5T%6055)B?5!
M5%-(B?M(@^PH9$B+!"4H````2(E%R#'`,<"`/CT/E,!)`<5,B>_H)^#__TB-
M=<1(B=])B<0QP.B&^___2(7`#X0%`0``2(G'28G&Z`+@__],.>`/@]$```!,
M8T7$3(L]KHH``$G!X`,/M@.$P`^$IP$``#P]#X2?`0``2(G8#Q]```^V4`%(
M@\`!A-)T!8#Z/77O2"G82)A*C7P@`DV)QDR)1;A-`S?H]M[__TF)!DB%P'10
M28L'3(M%N$B-2P%*BQ0`#[8#B`(\/70;A,!U!NL5/#UT$0^V`4B#P@%(@\$!
MB`*$P'7KQ@(],<!F#Q]$``!!#[9,!0"(3`(!2(/``83)=>Y(BT7(9$@K!"4H
M````#X47`0``2(/$*%M!7$%=05Y!7UW##Q]``#'`9@\?1```00^V5`4`08@4
M!DB#P`&$TG7NZ[X/'T``3(L]P8D``$V+#TF#.0`/A,,```!,B<A%,?9F#Q]$
M``!(@\`(1(GR08/&`4B#.`!U[XU*`TACR4C!X0.+!1>*``"%P'5C2(G/3(E-
ML,<%`HH```$```!(B4VXZ/G=__](B<=(A<`/A$____]-8\9(BTVX2(MUL$G!
MX`-,B<),B46XZ%+@__],BT6X28D'2(G'08U&`42)=<1(F$C'!,<`````Z7?^
M__^03(G/2(G.Z`7@__])B0=(B<=(A<`/A/C^__]-8\9)P>`#Z\4/'T0``#'`
MZ7?^__^Y$````$4Q]NE7____Z!_?__]F9BX/'X0```````\?0`#S#Q[Z2(L%
M]8@``$B+%?:(``!(C0V':0``2(TU&BD``&1(BSCII]___P\?@`````#S#Q[Z
M54B)Y4%505132('L`!```$B##"0`2('L`!```$B##"0`2(/L*&1(BP0E*```
M`$B)1=@QP$B-G=#O__],C:7`W___Z%7=__],C0WT*```N@$0``!(B=]!B<!(
MC0WF*```O@(````QP.@`W___2(G?N@`0``!,B>;H`-[__S'_A<!X,D2-:`%(
MB<--8^U,B>_HF-S__TB)QTB%P'082&/;3(GI3(GF2(G:Z-_<___&!!@`2(G'
M2(M%V&1(*P0E*````'412('$*"```$B)^%M!7$%=7</H`][__P\?`/,/'OKI
M%____P\?@`````#S#Q[Z54B)Y4%7059!54%44TB![``0``!(@PPD`$B![+@`
M``!D2(L$)2@```!(B47(,<!)B?Q)B?5(C3TH*```2(VU+.___^@4^/__OB\`
M``!,B>=(B</H1-W__TB%P'0_,<!,B>9(C3T$*```Z![\__],B>!(BU7(9$@K
M%"4H````#X6%`0``2(UEV%M!7$%=05Y!7UW#9@\?A```````3(GO3(TMU"<`
M`.@AW?__3(GN2(G'Z%;=__])B<9(A<!TGT&`/@`/A.(````/'T``2(7;=!-,
MB?9(B=_H(-W__X7`#X2F````3(GWZ`#<__])C50&_TF)QTDYUG(/ZQV0Q@(`
M2(/J`4DYUG0%@#HO=.],B??HU]O__TF)QTR)Y^C,V___28U$!P%(/?\/```/
MARS___](@^P(3(V]P.___TV)\#'`052Z`!```+X"````3(G_2(T-*2@``$R-
M#1XG``#H&=W__TB-M3#O__],B?_HBMO__UI9A<!U$HN%2.___R4`\```/0"`
M``!T4DR)[C'_Z'C<__])B<9(A<`/A+W^__]!@#X`#X4B____2(7;=`6`.RYT
M&$&_`0```$R--:$F``#I4O___V8/'T0``(![`0!TN.O@#Q^$``````"^`0``
M`$R)_^BCW/__A<!UG4R)_DB-/78F``#HD/K__TR)_^C(V___Z6C^___HWMO_
M_V9F+@\?A```````#Q\`\P\>^E6^+P```$B)Y5-(B?M(@^P(Z";;__](C5`!
M2(7`2`]%VDB)WTB+7?C)Z7[;__]F9BX/'X0```````\?`/,/'OI52(GE0513
M2('L`!```$B##"0`2(/L$&1(BP0E*````$B)1>@QP$B%_P^$S0```(`_`$B)
M^P^$P0```.A,VO__2(G"2(U``4@]`!````^'X0```$R-I>#O__],B>>#^`AR
M#HG!2(G>P>D#\TBE2(GS,<FH!'0)BPN)#[D$````J`)T#D0/MP0+9D2)!`](
M@\$"J`%T!P^V!`N(!`])C404_TDYQ'(2ZQ4/'T``Q@``2(/H`4PYX'0%@#@O
M=.^^+P```$R)Y^@RVO__2(7`="U).<1R6$R)Y^B0VO__2(M5Z&1(*Q0E*```
M`'5-2('$$!```%M!7%W##Q]$``!(BT7H9$@K!"4H````=2U(@<00$```2(T]
MZ20``%M!7%WI2MK__V8N#Q^$``````#&``#KHP\?`#'`ZZ3H3]K__V9F+@\?
MA```````#Q]``/,/'OI52(GE05=!5D%5051,C26[)```4TB-7<1(@^P89$B+
M!"4H````2(E%R#'`D#'`2(G>3(GGZ'/T__](A<!T-DB+!;>#``!(8U7$2(L`
M2(T$T$B+4`A(B1!(A=)TT$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-)5PD
M``"0,<!(B=Y,B>?H(_3__TB%P'0V2(L%9X,``$AC5<1(BP!(C0302(M0"$B)
M$$B%TG302(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE%"0``)`QP$B)WDR)
MY^C3\___2(7`=#9(BP47@P``2&-5Q$B+`$B-!-!(BU`(2(D02(72=-!(BU`0
M2(/`"$B)$$B%TG7PZ[YF#Q]$``!,C27-(P``D#'`2(G>3(GGZ(/S__](A<!T
M-DB+!<>"``!(8U7$2(L`2(T$T$B+4`A(B1!(A=)TT$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$R-)80C``"0,<!(B=Y,B>?H,_/__TB%P'0V2(L%=X(``$AC
M5<1(BP!(C0302(M0"$B)$$B%TG302(M0$$B#P`A(B1!(A=)U\.N^9@\?1```
M3(TM1",``)`QP$B)WDR)[^CC\O__2(7`=#9(BP4G@@``2&-5Q$B+`$B-!-!(
MBU`(2(D02(72=-!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C2VI(@``D#'`
M2(G>3(GOZ)/R__](A<!T-DB+!=>!``!(8U7$2(L`2(T$T$B+4`A(B1!(A=)T
MT$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-/;`B``"0,<!(B=Y,B?_H0_+_
M_TB%P'0V2(L%AX$``$AC5<1(BP!(C0302(M0"$B)$$B%TG302(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```3(TU:B(``)`QP$B)WDR)]^CS\?__2(7`=#9(BP4W
M@0``2&-5Q$B+`$B-!-!(BU`(2(D02(72=-!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$```QP$B)WDB-/1\B``#HI_'__TB%P'0Z2(L%ZX```$AC5<1(BP!(C030
M2(M0"$B)$$B%TG3,#Q]``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(G>
M2(T];2$``.A7\?__2(7`=#I(BP6;@```2&-5Q$B+`$B-!-!(BU`(2(D02(72
M=,P/'T``2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(G>2(T]BR$``.@)\?__
M2(7`=`U(B<9,B?<QP.@G]?__,<!(B=Y(C3UY(0``Z.;P__](A<!T$4B)QDB-
M/7<A```QP.@`]?__2(G>2(T]<2$``#'`Z+_P__](B<9(A<!T.$R)[S'`Z-WT
M__](BT7(9$@K!"4H````=41(@\083(GG2(TU7"$``#'`6T%<05U!7D%?7>FO
M]/__,<!(B=Y(C3TN(0``Z&[P__](A<!TO$B)QDR)_S'`Z(ST___KK>CEU?__
M#Q]$``#S#Q[Z54B-/:,@``!(B>5(@^P09$B+!"4H````2(E%^#'`2(UU].@E
M\/__2(7`=#`/MA"`^C`/E,"$T@^4P@G0@_`!#[;`2(M5^&1(*Q0E*````'4/
MR<-F#Q^$```````QP.OBZ'?5__\/'X``````\P\>^E5(B>5(@>S0````2(FU
M6/___TB)E6#___](B8UH____3(F%</___TR)C7C___^$P'0@#RE%@`\I39`/
M*56@#RE=L`\I9<`/*6W0#REUX`\I??!D2(L$)2@```!(B85(____,<!(C440
M2(GZ2(V-,/___TB)A3C___^^`@```$B-A5#___](B85`____2(L%X7X``,>%
M,/___P@```#'A33___\P````2(L`2(G'Z.K3__^__P```.C`TO__54B)Y4%5
M05133(V<)```__](@>P`$```2(,,)`!,.=QU[TB#[!BZ`@```#'V9$B+!"4H
M````2(E%V#'`08G]2(V=T/_^_^C5U/__3(U@_TR)XDC!^C](P>HP28T$%`^W
MP$@IT$DIQ`^(GP````\?`#'23(GF1(GOZ*/4__](@_C_#X2<````N@@``0!(
MB=Y$B>_H2=+__X/X_W1Y2)A(@_@'=E1(C40#^$@YV')*2(T5*WX``.L29@\?
MA```````2(/H`4@YV'(O2(L*2#D(=>](*=A,`>!(BU789$@K%"4H````=4M(
M@<08``$`6T%<05U=PP\?0`!)@>P```$`28'\``#__P^%9/___TC'P/_____K
MPDB-/=\>```QP.@=_O__2(T]Q!X``#'`Z`_^___H>M/__V8N#Q^$``````#S
M#Q[Z54B)Y>BCT___B<?H+-+__TB%P'0#2(L`7<-FD/,/'OI52(GE05=!5DB-
M=<1!54R-+8X>``!!5$F)_$R)[U-(@^P89$B+!"4H````2(E%R#'`Z(;M__](
MA<!T"(`X`$B)PW4Q2(M%R&1(*P0E*`````^%?P```$R)YDB-9=A,B>\QP%M!
M7$%=05Y!7UWI>_'__P\?`$R)Y^C0T?__2(G?28G&Z,71__]-C7P&`DR)_^@(
MT?__2(/L"$R)^DV)X%-(B<=)B<9,C0TN'0``2(T-+1X``+X"````,<#H'=/_
M_UA:2(M%R&1(*P0E*````'4%3(GVZX3H<M+__V:0\P\>^E5(C0W2'0``9D@/
M;L%(C0UA'0``2(GE05=!5DR-O;3^__]!54R)_D%44TB![$@!``!(B;VH_O__
M2(T]I1P``&1(BP0E*````$B)1<A(C06/'```2,>%\/[__P````!(QX4H____
M`````$C'A=#^__\`````9D@/;LA(C05?'0``9@]LP69(#V[02(T%5QT```\I
MA>#^__]F2`]NP4B-#>\<``!F2`]NV&8/;,)(C04]'0``#Q&%"/___V9(#V[!
M2(T-)1T``&9(#V[@9@]LPS'`#Q&%&/___V9(#V[!9@]LQ`\IA<#^___H[^O_
M_TB%P'0,@#@`2(G##X4&!0``Z*G1__^)Q^@RT/__2(7`#X0Y!```3(LP387V
M#X0M!```3(GWZ$70__],C6P``4R)[TR)Z^B%S___10^V!DB)A:#^__])B<1%
MA,!T4V:03(GJ10^VP$R)YS'`2(T-FAP``+X"````28/&`>B/T?__3#GK3(GJ
M10^V!D@/0]-(B=!,*>A(@\`"2#G02`]"PDDIU4F#Q`)-C6P%_D6$P'6O3(VM
M`/___TB-/=$;``#K%`\?@`````!)BWT(28/%"$B%_W0[3(G^,<#H$>O__TF)
MQ$B%P'3A@#@`=-Q(B<?HW.O__X7`=-!,B>?H8-#__TF)Q$B%P'5(#Q^$````
M``!,C:W@_O__38ME`$V%Y'0P08`\)``/A"4#``!,B>?HG>O__X7`#X4-`0``
M38ME"$F#Q0A-A>1UV`\?A```````3(GGZ"C/__](BYV@_O__28G%2(G?Z!;/
M__]%C;0%!`0``$UC]DR)]^A3SO__4TV)X$R-#8@:``!)B<5(C06)&P``3(GR
MO@(```!02(T-<!L``$R)[S'`Z&30__],B>^^P`$``.C7T/__7T%8@_C_=1+H
MBL___T2+"$&#^1$/A1(#``!(C84P____3(GO2(G&2(F%F/[__^C$S___B<.%
MP'1V2(N%J/[__TV)Z+X"````2(T5R!L``$B+"$B+!79Y``!(BS@QP.ADS?__
M13'D2(M%R&1(*P0E*`````^%H@0``$B-9=A,B>!;05Q!74%>05]=PP\?0`!,
MB>=)@\4(Z`S/__])B<1(A<`/A+?^___IZ_[__P\?`(N%2/___R4`\```/0!`
M```/A73___]$BZ5,____Z#;/__]!.<0/A5____^+A4C___\E_P$``#W``0``
M#X5)____3(GWZ!_-__],B?Y(C3TG&@``28G$,<#H*^G__TB%P`^$@@(``$B+
MC:C^__](B<9(BSGHL/#__TB)A:#^__](A<`/A&`"``!(B[V@_O__Z(3-__](
MB<*#^`-^3$B+C:#^__](F$B--0P:``!(B960_O__2(U\`?SH:\[__X7`=2=(
MBY60_O__@_H$#X0Y`P``2(N-H/[__XU"^TB8@#P!+P^$(P,``)!,B?Y,C3WU
M&```,<!,B?_HC.C__TB%P`^$`P(```^V`(3`#X3X`0``/#`/A/`!``!,B?](
MC34R&0``,<#HC^S__TR-/<P9``#HH\S__T%73(GR38GH4$R-#6,8``"^`@``
M`$R)YTB-#8@9```QP.A-SO__6%KK2F8/'X0``````.A[S?__@S@1=4GH8<S_
M_X/#`4B#[`A-B>A!5TR-#1X8``!,B?),B>=32(T-4AD``+X"````4#'`Z`/.
M__](@\0@OL`!``!,B>?H<L[__X/X_W2M3(GOZ$7,__],B>9(C3W#%P``,<#H
MY.O__TR)Y^CL^?__Z=;]__\/'X``````13'DZ?C\__\/'X0``````$B+O<#^
M__](C9W`_O__2(7_="8/'T0``#'`3(G^Z&[G__](A<!T!8`X`'5$2(M["$B#
MPPA(A?]UW[\-````NPT```!,C34]&```0;T-````Z!O+__]!N%,```!(B86@
M_O__28G$Z9;[__]F#Q]$``!(B<?HB,S__TF)QDB%P'2LZ4[[__](BX6H_O__
M38GHO@(```!(C165&```2(L(2(L%@W8``$B+.#'`Z''*___I"/W__P\?0`!(
MB<?H$/G__TB+1<AD2"L$)2@````/A:$!``!(C6782(G?6T%<05U!7D%?7>D7
MS/__#Q^``````$B+A:C^__](BP!(B86@_O__Z8K]__]F+@\?A```````2(N]
MH/[__S'V,<#H@,O__XG'A<`/A/;]__^)A:C^___H._?__TB%P`^(XOW__XN]
MJ/[__S'22(UP]DB)A:#^___H.LS__XN]J/[__[H&````2(VUNO[__^CCR?__
MB[VH_O__2(N-H/[__TB#^`8/A?4```"!O;K^__\`0T%##X6,_?__9H&]OO[_
M_TA%#X5]_?__,=)(C7'.B;VH_O__Z-S+__^+O:C^__^Z*````$B+G9C^__](
MB=[H@LG__TB#^"@/A:$```!(C04E%P``O@(```!-B>A,B?+&A5C___\`2(T-
MW18``$R-#;$5``!,B>=0,<!3Z*7+__]97NFQ_?__2(N%J/[__TB+4`A(A=(/
MA,K\__](B==(B96H_O__Z.O)__](@_@##X:Q_/__2(N5J/[__TB--7@6``!(
MC7P"_.C9RO__2(N5J/[__X7`2`]%E:#^__](B96@_O__Z7S\___HI\K__TB-
M/4H6```QP.@I]?__9@\?A```````\P\>^E5(C3TW%0``2(GE055!5$R-;=13
M3(GN2(/L&$B+'5IT``!D2(L$)2@```!(B478,<!D3(LC00^VA"2P````08B$
M)+$````QP.BOY/__2(7`=`F`.#$/A&D!```QP.CJ[___9$R+(TR)Y[D#````
MN@$```!(C37U%0``Z'W(__])B<1(A<!T*4B+0!!D2(L[2(T5VQ4``$B+,.B.
MR/__28M$)!!(BS#V1@Y`#X5,`0``9$B+.[D#````N@$```!(C36Q%0``Z#+(
M__])B<1(A<!T+DR)[DB-/3$4```QP.@9Y/__2(G"2(7`#X3M````28M$)!!D
M2(L[2(LPZ"S(__]D2(L[N@$```!(C35H%0``Z$?'__]D2(L[2(T5;14``$B)
MQN@$R/__9$B+`TR)[DB-/<X3``#&@+$`````,<#HN./__TB)!:%S``!(B<-(
MA<!T0;[``0``2(G?Z#S*__^-4`&#^@%V"8/X$0^%F0```$B+1=AD2"L$)2@`
M```/A:,```!(@\086T%<05U=PP\?1```2(L]67,``.A\]O__2(D%17,``$B)
MPTB%P'6D2(T]?A4``#'`Z!_)__\/'X``````@'@!``^$F/[__^F(_O__9@\?
MA```````2(L%$7,``$B+,$F+1"002(LXZ%GF___I"/___P\?0`!D2(L[Z'?(
M___IIO[__XG!2(L%X7(``$B)VDB-/3\5``!(BS`QP.BUR/__Z&#(___S#Q[Z
M54B)Y4%44TB-=>1(B?M(C3T6$P``2(/L$&1(BP0E*````$B)1>@QP.B?XO__
M2(7`=!P/MA"`^C`/E,"$T@^4P@C0=0I(A=MT!8`[`'4>2(M%Z&1(*P0E*```
M`'5Q2(/$$%M!7%W#9@\?1```2(G?Z%CL__^^+P```$B)QTF)Q.A(Q___2(U0
M`4B%P$P/1>),B>?HI<?__[H$````2(TU5!,``$B)Q^CQQ?__A<!UGTB+1>AD
M2"L$)2@```!U$$B#Q!!(B=];05Q=Z6[C___HB<?__V8/'X0``````/,/'OI5
MOX````!(B>7HOL7__V8/;P464@``2,=`,``````/$0!F#V\%$U(``,=`>```
M```/$4`09@]O!1!2```/$4`@7<-F+@\?A```````\P\>^E5(8\)(B>5!5TF)
M_T%628G&055!5$V-9SA32(GS2(/L&$B+?RA)BU<PC33'2#G^28EW*$B#T@!(
MP>@=2`'028E',$EC1WB%P`^%]@```$&#_C\/CCP!``!!@^Y`1(GPP>@&1(UH
M`8E%R$G!Y09)`=T/'T``\P]O`TR)_TB#PT!!#Q$$)/,/;TO000\13"00\P]O
M4^!!#Q%4)"#S#V];\$$/$5PD,.BBRO__3#GK=<6+1<C!X`9!*<9)8\9(@_@(
M<EM)BU4`28UW0$B#YOA)B5<X28M4!?A)B50$^$DI]$P!X$TIY4B#X/A(@_@(
M<AA(@^#X,=))BWP5`$B)/!9(@\((2#G"<NY%B7=X2(/$&%M!7$%=05Y!7UW#
M#Q\`J`1U?$B%P'3A00^V50!!B%<XJ`)TU$$/MU0%_F9!B50$_NO&#Q]``+I`
M````28T\!$B)WBG"1#GR00]/UD&)U4ACTDB)5<CHM,;__T&+1WA$`>A!B4=X
M@_A`=9)(BT7(3(G_12GN2`'#Z,+)___IO_[__P\?1```28G=Z1S___]!BU4`
M08E7.$&+5`7\08E4!/SI4____V8/'X0``````/,/'OI52(GE05=,C7XX059!
M54%428G\4TB)\TB#[`A,BW8H3(MN,$R)\$C!Z`.#X#^-4`'&1`8X@$ACRH/Z
M.`^.NP$``+Y`````3`'Y*=9T#S'`B<*#P`'&!!$`.?!R\TB)W^@HR?__9@_O
MP`\10SA)QT<P`````$$/$4<000\11R!,B>I!#[;&38GP3(GW2,'J&$C!X`A,
MB>E)P>@028G13(GR2,'O&`^V]DR)ZDC!Z1!("?!!#[;P#[;)2,'@"$@)\$`/
MMO=(B=](P>`(2`GP00^V]4C!X`A("?`/MO9!#[;12,'@"$@)\$C!X`A("<A(
MP>`(2`G02(E#<.B/R/__2(L#2(G?2,'H&$&(!"1(BP-(P>@008A$)`%(BP,/
MML1!B$0D`DB+`T&(1"0#2(M#"$C!Z!A!B$0D!$B+0PA(P>@008A$)`5(BT,(
M#[;$08A$)`9(BT,(08A$)`=(BT,02,'H&$&(1"0(2(M#$$C!Z!!!B$0D"4B+
M0Q`/ML1!B$0D"DB+0Q!!B$0D"TB+0QA(P>@808A$)`Q(BT,82,'H$$&(1"0-
M2(M#&`^VQ$&(1"0.2(M#&$&(1"0/2(M#($C!Z!A!B$0D$$B+0R!(P>@008A$
M)!%(BT,@#[;$08A$)!)(BT,@08A$)!-(@\0(6T%<05U!7D%?7>ECPO__#Q\`
MN#@```!)`<\Q_RG0@_@(<D=)C4\(B<))QP<`````2<=$%_@`````2(/A^$DI
MST0!^(/@^(/X"`^"1?[__X/@^#'2B=:#P@A(B3PQ.<)R\^DN_O__#Q]``*@$
M=22%P`^$'O[__T'&!P"H`@^$$O[__S'29D&)5`?^Z07^__\/'P!!QP<`````
M0<=$!_P`````Z>W]__]F+@\?A```````D/,/'OI(BPWM;```Z>#`___S#Q[Z
M2(/L"$B#Q`C#````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%53
M15(`55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@!S:&]R
M="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,P`M
M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M`````/____\`````_____P`````!(T5G`````(FKS>\`````_MRZF`````!V
M5#(0`````/#ATL,````````````````!&P,[!`$``!\```!@;___.`$``-!R
M__]@`0``X'+__W@!``!`=O__``4``%!X__\@`0``0'G__Y`!``"0C___P`$`
M`'"0___L`0```)'__Q`"``"`DO__/`(``."2__]<`@``P)/__X@"```0EO__
MN`(``$"6___,`@``()?___0"```PE___"`,``%"9__\T`P``D)G__U0#``#@
MFO__A`,``$"?__^T`P``L)___]@#``!PH/__]`,``+"A__\<!```T*'__SP$
M``"PHO__;`0``)"J__^D!```P*S__]`$``"@K?__*`4``/"M__](!0``L*__
M_W@%``!0LO__J`4````````4``````````%Z4@`!>!`!&PP'")`!```4````
M'````"AW__\F`````$0'$``````D````-````"!N__]P`P````X01@X82@\+
M=PB``#\:.2HS)"(`````%````%P```!H<?__$```````````````%````'0`
M``!@<?__8`,`````````````+````(P```"H=___0Q8```!!#A"&`DH-!F&/
M`XX$C06,!H,'`Q$6"@P'"$$+````*````+P```#(C?__U`````!!#A"&`D,-
M!DV/`XX$C06,!H,'`G8*#`<(20L@````Z````'R.__^$`````$$.$(8"0PT&
M08,#`GD*#`<(00LH````#`$``.B.__]T`0```$$.$(8"0PT&4(\#C@2-!8P&
M@P<"0`H,!PA$"QP````X`0``/)#__UL`````10X0A@)1#09%@P-X#`<(*```
M`%@!``!\D/__X`````!!#A"&`D,-!E>.`XT$C`6#!@)^"@P'"$<+```L````
MA`$``#"1__]!`@```$$.$(8"0PT&1H\#C@2-!4:,!H,'`R,!"@P'"$4+```0
M````M`$``%"3__\I`````````"0```#(`0``;)/__]T`````10X0A@)##09A
MC0.,!(,%`JX*#`<(00L0````\`$``"24__\)`````````"@````$`@``()3_
M_Q("````10X0A@)##09<CP..!(T%C`:#!P)R"@P'"$H+'````#`"```4EO__
M,@````!%#A"&`D@-!D&#`U\,!P@L````4`(``#26__]!`0```$4.$(8"0PT&
M4XP#@P0"WPH,!PA&"V$*#`<(3PL````L````@`(``%27__];!````$4.$(8"
M0PT&2(\#C@2-!8P&2(,'`Q0$"@P'"$4+```@````L`(``(2;__]I`````$4.
M$(8"2@T&`D<*#`<(2@L````8````U`(``-";___``````$4.$(8"0PT&````
M)````/`"``!TG/__-@$```!!#A"&`D,-!F*-`XP$@P4"S0H,!PA%"QP````8
M`P``C)W__QX`````10X0A@)##095#`<(````+````#@#``",G?__W@````!%
M#A"&`D,-!DJ/`XX$C05)C`9+@P<"2@H,!PA("P``-````&@#```\GO__UP<`
M``!%#A"&`E8-!D2/`XX$5HT%C`:#!P/^`@H,!PA%"P/\`@H,!PA,"P`H````
MH`,``.2E__\P`@```$4.$(8"2@T&1(T#C`1,@P4#<P$*#`<(1@L``"P```#,
M`P``Z*?__]<`````10X0A@)##09'C`.#!`):"@P'"$<+`ET*#`<(10L``"0`
M``#\`P``.''__PX"````10X0A@)##09'C`.#!`-J`0H,!PA!"P`<````)`0`
M`'"H__]&`````$4.$(8"2`T&>`P'"````"P```!$!```H*C__[<!````10X0
MA@)&#09"CP-%C@1'C06,!D6#!P+^"@P'"$0+`"P```!T!```,*K__Y4"````
M10X0A@)##09"CP-*C@2-!8P&1(,'`^`!"@P'"$@+`!````"D!```H*S__Q``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````\"D```````"P*0````````$`````````Z`(````````!
M`````````/@"````````#```````````(`````````T`````````(&,`````
M```9`````````,C+````````&P`````````(`````````!H`````````T,L`
M```````<``````````@`````````]?[_;P````"P`P````````4`````````
M8`T````````&`````````)`$````````"@````````"!!`````````L`````
M````&``````````5`````````````````````P````````#8S0````````(`
M````````$`4````````4``````````<`````````%P````````"@%```````
M``<`````````(!,````````(`````````(`!````````"0`````````8````
M`````!X`````````"`````````#[__]O``````$```@`````_O__;P````"@
M$@```````/___V\``````0````````#P__]O`````.(1````````^?__;P``
M```$````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MV,L`````````````````````````````,"````````!`(````````%`@````
M````8"````````!P(````````(`@````````D"````````"@(````````+`@
M````````P"````````#0(````````.`@````````\"``````````(0``````
M`!`A````````("$````````P(0```````$`A````````4"$```````!@(0``
M`````'`A````````@"$```````"0(0```````*`A````````L"$```````#`
M(0```````-`A````````X"$```````#P(0`````````B````````$"(`````
M```@(@```````#`B````````0"(```````!0(@```````&`B````````<"(`
M``````"`(@```````)`B````````H"(```````"P(@```````,`B````````
MT"(```````#@(@```````/`B`````````",````````0(P```````"`C````
M````,",```````!`(P```````%`C````````8",```````!P(P```````(`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#X
M<@```````$=#0SH@*%5B=6YT=2`Q,RXR+C`M,C-U8G5N='4T*2`Q,RXR+C``
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YP;'0N<V5C`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````!@#````````&`,`````
M```<`````````````````````0```````````````````!,````'`````@``
M```````X`P```````#@#````````,`````````````````````@`````````
M```````````F````!P````(`````````:`,```````!H`P```````"0`````
M```````````````$````````````````````.0````<````"`````````(P#
M````````C`,````````@````````````````````!```````````````````
M`$<```#V__]O`@````````"P`P```````+`#````````X``````````&````
M``````@```````````````````!1````"P````(`````````D`0```````"0
M!````````-`(````````!P````$````(`````````!@`````````60````,`
M```"`````````&`-````````8`T```````"!!````````````````````0``
M`````````````````&$```#___]O`@````````#B$0```````.(1````````
MO``````````&``````````(``````````@````````!N````_O__;P(`````
M````H!(```````"@$@```````(``````````!P````$````(````````````
M````````?0````0````"`````````"`3````````(!,```````"``0``````
M``8`````````"``````````8`````````(<````$````0@````````"@%```
M`````*`4````````$`4````````&````&`````@`````````&`````````"1
M`````0````8``````````"``````````(````````!L`````````````````
M```$````````````````````C`````$````&`````````"`@````````("``
M``````!P`P``````````````````$``````````0`````````)<````!````
M!@````````"0(P```````)`C````````$````````````````````!``````
M````$`````````"@`````0````8`````````H",```````"@(P```````&`#
M```````````````````0`````````!``````````J0````$````&````````
M```G`````````"<````````@/```````````````````$```````````````
M`````*\````!````!@`````````@8P```````"!C````````#0``````````
M``````````0```````````````````"U`````0````(``````````'``````
M````<````````,!````````````````````0````````````````````O0``
M``$````"`````````,"P````````P+`````````$`0``````````````````
M!````````````````````,L````!`````@````````#(L0```````,BQ````
M````N`0```````````````````@```````````````````#5````#@````,`
M````````R,L```````#(NP````````@````````````````````(````````
M``@`````````X0````\````#`````````-#+````````T+L````````(````
M````````````````"``````````(`````````.T````&`````P````````#8
MRP```````-B[``````````(````````'``````````@`````````$```````
M``";`````0````,`````````V,T```````#8O0```````"@"````````````
M```````(``````````@`````````]@````$````#``````````#0````````
M`,`````````H````````````````````"````````````````````/P````(
M`````P`````````HT````````"C`````````*`````````````````````@`
M```````````````````!`0```0```#`````````````````````HP```````
M`"8````````````````````!``````````$``````````0````,`````````
M````````````````3L`````````*`0```````````````````0``````````
'````````````
